=====
Nabo
=====

,,,,

.. image:: https://files.osf.io/v1/resources/3kvwp/providers/osfstorage/5b48b0fae3cf560010d4da56?action=download&version=1&view_only=7ce3329d8b48473f9afefc848bebb63a&direct
  :width: 200
  :align: left
  :alt: Image

Nabo is a flexible Python package that allows projections of cells from one population to another using single-cell RNA-Seq data. Nabo works by setting one of the populations as a reference' and then maps cells from other populations ('targets') onto it. Nabo provides data implicit methods of verifying mapping quality, this allows users to clearly infer similarities between sub-populations across samples

Please refer to the `documentation <https://nabo.readthedocs.io>`__ to know more.

